# spec file for package ranger
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%{!?python_sitelib:  %global python_sitelib  %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
Name:           ranger
Version:        1.8.1
Release:        1.4
Summary:        Console File Manager
License:        GPL-3.0
Group:          Productivity/File utilities
Url:            http://ranger.nongnu.org
Source:         http://nongnu.org/ranger/ranger-%{version}.tar.gz
Source99:       ranger-rpmlintrc
BuildRequires:  python-devel >= 2.5.1
Requires:       file
Requires:       python-curses
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
%if 0%{?suse_version}
Recommends:     atool
Recommends:     highlight
Recommends:     mediainfo
Recommends:     w3m
%else
BuildRequires:  atool
Requires:       atool
%endif
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif
%if 0%{?suse_version}
%py_requires
%endif

%description
Ranger is a console file manager that gives you greater flexibility and a
good overview of your files without having to leave your text console. It
visualizes the directory tree in two dimensions: the directory hierarchy on
one, lists of files on the other, with a preview to the right.

The default keys are similar to those of Vim, Emacs and Midnight Commander,
though ranger is easily controllable with just the arrow keys or the mouse.

%prep
%setup -q
sed -e 's|#!/bin/python|#!%{_bindir}/env python|' -i doc/tools/convert_papermode_to_metadata.py

%build
python ./setup.py build

%install
python ./setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot}

rm -rf "%{buildroot}%{_datadir}/doc/ranger"

%if 0%{?suse_version}
%suse_update_desktop_file -r "%{name}" System FileManager
%endif

%files
%defattr(-,root,root)
%doc AUTHORS CHANGELOG.md README.md HACKING.md
%doc doc/colorschemes.txt
%doc doc/tools
%doc examples
%{_bindir}/ranger
%{_bindir}/rifle
%{python_sitelib}/ranger-%{version}-*.egg-info
%{python_sitelib}/ranger
%{_mandir}/man1/ranger.1*
%{_mandir}/man1/rifle.1*
%{_datadir}/applications/%{name}.desktop

%changelog
* Sat Jan 21 2017 aloisio@gmx.com
- Update to version 1.8.1
  * Fixed `:scout` break due to incompatible change
    in python 3.6
* Wed Dec 28 2016 jengelh@inai.de
- Trim filler words from description
* Sat Dec 24 2016 aloisio@gmx.com
- Update to version 1.8.0
  * scope.sh is now needed for the now fully scriptable image
    previews
  * Overhaul of version control system integration, now with
    threads
  * Fixed ranger not finding the location of w3mimgdisplay in
    most cases
  * Fixed many minor bugs
  * Added midnight-commander like multipane view, toggleable
    with `~` key. It displays the current directory of all the
    open tabs next to each other.
  * Added autodetect for 256 color support in scope.sh source
    code preview
  * Added macro `%%confdir` that expands to `~/.config/ranger`
    by default
  * Added possibility to toggle/cycle through options with
    `set <option_name>!`
  * Added `Mm`/`Ms` key to enable the linemode showing
    modification time
  * Added `yt`/`dt` keys to toggle whether file is in copy/cut
    buffer
  * Added `line_numbers` setting showing absolute/relative
    line numbers
  * Added `Alt-Left` and `Alt-Right` key bindings to move by
    words in console
  * Added previews for libreoffice files with `odt2txt`
  * Added `preview_images_method=urxvt` option for previewing
    images by changing the urxvt background (requires urxvt
    compiled with pixbuf support)
  * Added `clear_filters_on_dir_change` option
  * Added Travis-CI integration
  * Changed `zi` key to toggle `preview_images` option
  * Improved PEP8 compliance
  * Improved documentation
  * Improved UI by separating file path in title bar with a
    space from the  username/hostname for quick copy&pasting by
    shift+double-clicking on it.
- Dropped ranger.desktop now supplied from upstream
* Sat Nov  5 2016 aloisio@gmx.com
- Update to version 1.7.2
  * Fixed file name arguments passed to "sxiv" and "feh" when
    using ":flat"
  * Fixed removal of empty directories when using ":rename"
  * Fixed free disk space display on Mac OS X
  * Fixed `examples/vim_file_chooser` to work with gvim too
  * Fixed some other rare crashes and bugs
  * Fixed downward mouse wheel scrolling
  * Fixed warning about regex splits being drawin in title bar
    since python3.5
  * Really fixed "S" key binding not working when SHELL=fish
  * Improved doc/cheatsheet.svg
  * Added some entries to rifle.conf
  * Added key bindings pO and pP which work like po and pp but
    queue the operation in a first-in-first-out order.
  version 1.7.1
  * Added doc/cheatsheet.svg
  * Added examples/rc_emacs.conf, a config file adding
    emacs-like key bindings
  * Added "env" keyword in rifle.conf
  * Fixed ":bulkrename" command in python3
  * Fixed "S" key binding not working when SHELL=fish
  version 1.7.0
  * The default editor is now "vim" instead of "nano"
  * Added automatic updates of tags when a file is renamed
    from within ranger
  * Added "preview_images_method" which can be set to "iterm2"
    to use native iTerm2 image previews
  * Added ":rename_append" command to rename files without the
    file extension
  * Added ":linemode" command to change the way the files are
    displayed. Try this out by pressing M followed by one of
    the  suggested keys. New linemodes can be added with
    ranger.api.register_linemode().
  * Added ":filter_inode_type" command to only show
    directories, files or links
  * Added ":meta" command for managing custom file metadata
  * Added ":flat" command for displaying subdirectories
  * Added "solarized" colorscheme
  * Added generic ability to use scope.sh for image previews
  * Added video previews in scope.sh
  * Added option "sort_unicode" to sort according to unicode,
    not ASCII
  * ":mkdir" can now create multiple directory levels (like
    `mkdir -p`)
  * ":help" (key binding "?") is now interactive
  * ":find" (key binding "/") is now case insensitive by
    default
  * "ranger --copy-config=all" now copies a short sample
    commands.py rather than the full one, so that you can
    update ranger without having broken commands. The full
    commands.py is still copied to
    ~/.config/ranger/commands_full.py.
  * Fixed broken copying of symlinks
- Spec cleanup
* Mon Jul 15 2013 pascal.bleser@opensuse.org
- update to 1.6.1
- add required dependency on python-curses
* Thu May 26 2011 pascal.bleser@opensuse.org
- initial version (1.4.3)
